# SCP Scraper
A small Python library designed for scraping data from the SCP wiki. Allows for human-readable and AI dataset return styles for `scrape_scps`, allowing for easy retrieval of a fairly large corpus conducive to NLP model training. Currently in alpha, but future updates are planned.

## Planned future updates
Potential updates in the future to make scraping data from any website easy/viable, allowing for easy mass collection of data.
